<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }


    // This is your option name where all the Redux data is stored.
    $opt_name = "primax";

    // This line is only for altering the demo. Can be easily removed.
    $opt_name = apply_filters( 'primax/opt_name', $opt_name );

    /*
     *
     * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
     *
     */

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
		'class'                => 'admin-color-pimax',
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => esc_attr__( 'Primax Options', 'primax' ),
        'page_title'           => esc_attr__( 'Primax Options', 'primax' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => false,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the primax. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'primax'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'primax'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    
    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        $args['intro_text'] = sprintf( esc_attr__( '', 'primax' ), $v );
    } else {
        $args['intro_text'] = esc_attr__( '', 'primax' );
    }

    // Add content after the form.
    $args['footer_text'] = esc_attr__( '', 'primax' );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => esc_attr__( 'Support', 'primax' ),
            'content' => esc_attr__( 'Send us a mail by using our item support form.', 'primax' )
        ),
        
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = esc_attr__( 'Send us a mail by using our item support form.', 'primax' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    // ACTUAL DECLARATION OF SECTIONS
                Redux::setSection( $opt_name, array(
                    'title'  => esc_attr__( 'General Settings', 'primax' ),
                    'desc'   => esc_attr__( '', 'primax' ),
                    'icon'   => 'el-icon-home-alt',
                    // 'submenu' => false, // Setting submenu to false on a given section will hide it from the WordPress sidebar menu!
                    'fields' => array(

                     
					 
					
					array(
							'id' => 'textlogo',
							'type' => 'button_set',
							'title' => esc_attr__('Select Logo Format', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_attr__('Text Logo', 'primax'),
									'st2' => esc_attr__('Image Logo', 'primax'),
									
							),
							'default'  => 'st1'
					),
					 
					array(
							'id' => 'logopic',
							'type' => 'media',
							'compiler' => 'true',
							'title' => esc_attr__('Upload  Logo', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							'required' => array('textlogo', '=' , 'st2')
					),
					
					
					array(
							'id' => 'logotext',
							'type' => 'text',
							'title' => esc_attr__('Logo Text ', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							'required' => array('textlogo', '=' , 'st1')
					
					),
					
					
					
					
					
					
				  )
               ) );
			   
			   
			   
			   Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-idea',
                    'title'  => esc_attr__( 'Header Options', 'primax' ),
                    'fields' => array(
					
					array(
			                'id' => 'notice_headeroption',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Header Option', 'primax'),
			                'desc' => esc_attr__('Select header style of your site.', 'primax')
			            ),
					
					array(
							'id' => 'headerstyle',
							'type' => 'button_set',
							'title' => esc_attr__('Select Header Layout', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_attr__('Default', 'primax'),
									'st2' => esc_attr__('Layout 2', 'primax'),
									'st3' => esc_attr__('Layout 3', 'primax'),
									'st4' => esc_attr__('Layout 4', 'primax'),
									'st5' => esc_attr__('Layout 5', 'primax'),
									
							),
							'default'  => 'st1'
					),
					
					
					array(
			                'id' => 'notice_headerinfo',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Top Header Option', 'primax'),
			                'desc' => esc_attr__('Working only Header style 1 & style 2', 'primax'),
							
			            ),
						
						array(
			                'id' => 'notice_headerinfophn',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Field For Phone Number', 'primax'),
			                'desc' => esc_attr__('', 'primax'),
							
			            ),
						
						array(
							'id' => 'priphnicon',
							'type' => 'text',
							'title' => esc_attr__('Icon Class', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							'desc' => esc_attr__('Use Font Awesome icon Class.', 'primax'),
						
						),
						
						array(
							'id' => 'priphntitle',
							'type' => 'text',
							'title' => esc_attr__('Title', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							'desc' => esc_attr__('', 'primax'),
						
						),
						
						array(
							'id' => 'priphnnum',
							'type' => 'text',
							'title' => esc_attr__('Phone Number', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							'desc' => esc_attr__('', 'primax'),
						
						),
						
						
						array(
			                'id' => 'notice_headerinfomail',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Field For Email', 'primax'),
			                'desc' => esc_attr__('', 'primax'),
							
			            ),
						
						array(
							'id' => 'priemailicon',
							'type' => 'text',
							'title' => esc_attr__('Icon Class', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							'desc' => esc_attr__('Use Font Awesome icon Class.', 'primax'),
						
						),
						
						array(
							'id' => 'priemailtitle',
							'type' => 'text',
							'title' => esc_attr__('Title', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							'desc' => esc_attr__('', 'primax'),
						
						),
						
						array(
							'id' => 'priemailnum',
							'type' => 'text',
							'title' => esc_attr__('Email Address', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							'desc' => esc_attr__('', 'primax'),
						
						),
						
						
						array(
			                'id' => 'notice_headerinfotime',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Extra Field', 'primax'),
			                'desc' => esc_attr__('', 'primax'),
							
			            ),
						
						array(
							'id' => 'pritimeicon',
							'type' => 'text',
							'title' => esc_attr__('Icon Class', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							'desc' => esc_attr__('Use Font Awesome icon Class.', 'primax'),
						
						),
						
						array(
							'id' => 'pritimetitle',
							'type' => 'text',
							'title' => esc_attr__('Title', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							'desc' => esc_attr__('', 'primax'),
						
						),
						
						array(
							'id' => 'pritimenum',
							'type' => 'text',
							'title' => esc_attr__('Content', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							'desc' => esc_attr__('', 'primax'),
						
						),
					
					
                    )
                ) );
				
				if (class_exists('WooCommerce')) {
          Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-viadeo',
                    'title'  => esc_attr__( 'Shop Options', 'primax' ),
                    'fields' => array(
					
					array(
							'id' => 'wr-pro-hd',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_attr__('Product Page Heaader Options', 'primax'),
							'desc' => esc_attr__('Select Product Page Header Style', 'primax')
							
					  ),	
					
					
					array(
							'id' => 'product-header-wr-img',
							'type' => 'media',
							'compiler' => 'true',
							'title' => esc_attr__('Upload Header Image', 'primax'),
							'subtitle' => esc_html__('Upload Shop Page Header Image.  Working Only Header Style 5.', 'primax'),
							
						
					),
					
					array(
							'id' => 'product-sin-header-wr-img',
							'type' => 'media',
							'compiler' => 'true',
							'title' => esc_attr__('Upload Header Image', 'primax'),
							'subtitle' => esc_html__('Upload Product Details Page Header Image.  Working Only Header Style 5.', 'primax'),
							
						
					),
					
					
					
                    )
                    )
                );   
				
	}
			
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-bullhorn',
                    'title'  => esc_attr__( 'Blog Options', 'primax' ),
                    'fields' => array(
					
					array(
							'id' => 'blogtyle',
							'type' => 'button_set',
							'title' => esc_attr__('Select Blog Layout', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_attr__('Left Sidebar', 'primax'),
									'st2' => esc_attr__('Right Sidebar', 'primax'),
									
									
							),
							'default'  => 'st1'
					),
					
					array(
							'id' => 'header-blog-img-opt',
							'type' => 'media',
							'compiler' => 'true',
							'title' => esc_attr__('Upload Header Image', 'primax'),
							'subtitle' => esc_html__('Upload Index Page Header Image.  Working Only Header Style 5.', 'primax'),
							
						
					),
					
					array(
							'id' => 'blogtitle',
							'type' => 'text',
							'title' => esc_attr__('Index Title ', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							
							
							
					),
					
					
                    )
                ) );
				
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-bullhorn',
                    'title'  => esc_attr__( 'Coundown Options', 'primax' ),
                    'fields' => array(
					
					array(
			                'id' => 'notice_eventcount',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Event Countdown Option. ', 'primax'),
			                'desc' => esc_attr__('', 'primax'),
							
			            ),
				
					array(
							'id' => 'eventcoundown',
							'type' => 'text',
							'title' => esc_attr__('Set Time ', 'primax'),
							'subtitle' => esc_attr__('This section for Event intro Element.  ', 'primax'),
							'desc' => esc_attr__('Date Format: 2018/05/11', 'primax')
							
					),
					
					
					array(
			                'id' => 'notice_comingcount',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Coming Soon Option. ', 'primax'),
			                'desc' => esc_attr__('', 'primax'),
							
			            ),
						
					array(
							'id' => 'comingcoundown',
							'type' => 'text',
							'title' => esc_attr__('Set Time ', 'primax'),
							'subtitle' => esc_attr__('This section for coming soon page template.  ', 'primax'),
							'desc' => esc_attr__('Date Format: 2018/05/11', 'primax')
							
					),
					
					array(
							'id' => 'comingcoundowntitle',
							'type' => 'text',
							'title' => esc_attr__('Title ', 'primax'),
							'subtitle' => esc_attr__('This section for coming soon page template.  ', 'primax'),
							'desc' => esc_attr__('', 'primax')
							
					),
					
					array(
							'id' => 'comingcoundowncontent',
							'type' => 'text',
							'title' => esc_attr__('Content', 'primax'),
							'subtitle' => esc_attr__('This section for coming soon page template.  ', 'primax'),
							'desc' => esc_attr__('', 'primax')
							
					),
					
					
                    )
                ) );
				
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-leaf',
                    'title'  => esc_attr__( 'Social Options', 'primax' ),
                    'fields' => array(
					
					
					array(
							'id' => 'facebook',
							'type' => 'text',
							'title' => esc_attr__('Facebook URL ', 'primax'),
							'subtitle' => esc_attr__('Write Social URL', 'primax'),
					),
					
					array(
							'id' => 'twitter',
							'type' => 'text',
							'title' => esc_attr__('Twitter URL ', 'primax'),
							'subtitle' => esc_attr__('Write Social URL', 'primax'),
					),
					
					array(
							'id' => 'pinterest',
							'type' => 'text',
							'title' => esc_attr__('Pinterest URL ', 'primax'),
							'subtitle' => esc_attr__('Write Social URL', 'primax'),
					),
					
					
					
					array(
							'id' => 'behance',
							'type' => 'text',
							'title' => esc_attr__('Behance URL ', 'primax'),
							'subtitle' => esc_attr__('Write Social URL', 'primax'),
					),
					
					array(
							'id' => 'dribbble',
							'type' => 'text',
							'title' => esc_attr__('Dribbble URL ', 'primax'),
							'subtitle' => esc_attr__('Write Social URL', 'primax'),
					),
					
					array(
							'id' => 'gplus',
							'type' => 'text',
							'title' => esc_attr__('Google URL ', 'primax'),
							'subtitle' => esc_attr__('Write Social URL', 'primax'),
					),
					
					array(
							'id' => 'linkedin',
							'type' => 'text',
							'title' => esc_attr__('Linkedin URL ', 'primax'),
							'subtitle' => esc_attr__('Write Social URL', 'primax'),
					),
					
					array(
							'id' => 'youtube',
							'type' => 'text',
							'title' => esc_attr__('Youtube URL ', 'primax'),
							'subtitle' => esc_attr__('Write Social URL', 'primax'),
						
					),
					
					array(
							'id' => 'vimeo',
							'type' => 'text',
							'title' => esc_attr__('Vimeo URL ', 'primax'),
							'subtitle' => esc_attr__('Write Social URL', 'primax'),
							
					),
					
					array(
							'id' => 'slack',
							'type' => 'text',
							'title' => esc_attr__('Slack ', 'primax'),
							'subtitle' => esc_attr__('Write Social URL', 'primax'),
							
					),
					
					array(
							'id' => 'instagram',
							'type' => 'text',
							'title' => esc_attr__('Instagram URL ', 'primax'),
							'subtitle' => esc_attr__('Write Social URL', 'primax'),
							
					),
					
					array(
							'id' => 'tumblr',
							'type' => 'text',
							'title' => esc_attr__('Tumblr URL ', 'primax'),
							'subtitle' => esc_attr__('Write Social URL', 'primax'),
							
					),
					
					
                    )
                ) );
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-brush',
                    'title'  => esc_attr__( 'Styling', 'primax' ),
                    'fields' => array(
					
					array(
                            'id'       => 'opt-theme-style',
                            'type'     => 'color',
                            'title'    => esc_attr__( 'Theme Color Option', 'primax' ),
                            'subtitle' => esc_attr__( 'Only color validation can be done on this field type', 'primax' ),
                            'desc'     => esc_attr__( 'Change all global color.', 'primax' ),
                            //'regular'   => false, // Disable Regular Color
                            //'hover'     => false, // Disable Hover Color
                            //'active'    => false, // Disable Active Color
                            //'visited'   => true,  // Enable Visited Color
                            
                        ),
						
					

                    )
                ) );
				
				Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-text-width',
                    'title'  => esc_attr__( 'Typography', 'primax' ),
                    'fields' => array(     

						array(
			                'id' => 'notice_critical11',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Entry Headings', 'primax'),
			                'desc' => esc_attr__('Entry Headings in posts/pages', 'primax')
			            ),

						array(
                            'id'          => 'logotextwr1',
                            'type'        => 'typography', 
                            'title'       => __('Text Logo', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('#logo a h2'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the Logo Text font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
                        array(
                            'id'          => 'typography-h1',
                            'type'        => 'typography', 
                            'title'       => __('H1', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h1, .blog-single-post-title, .page-header-title'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the Heading font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),	
                        array(
                            'id'          => 'typography-h2',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('H2', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h2, .bl-item-title, .bl-item-title h2, .hs-title, .gli-alter-2 .gl-item-title, .gl-item-title, .gli-alter-1 .gl-item-title, .gli-alter-3 .gl-item-title'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the Heading font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),      
                        ),
						
						array(
                            'id'          => 'typography-h2-hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('H2 Hover', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h2:hover, .bl-item-title:hover, .bl-item-title h2:hover, #body-content .gli-alter-2 .gl-item-title:hover, #body-content .gli-alter-1 .gl-item-title:hover, .gli-alter-3 .gl-item-title:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the Heading Hover font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),      
                        ),
                        array(
                            'id'          => 'typography-h3',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('H3', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h3, .blog-text h3, .comment-form-holder h3, .comments-holder h3, .project-details h3, .blog-text h3 a, .comment-form-holder h3 a, .comments-holder h3 a, .project-details h3 a, .enter-wrap h3, .fixed-info-container h3, .fw-info-container h3, .font-alter-1'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the Heading font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),

						array(
                            'id'          => 'typography-h3-hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('H3 Hover', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h3:hover, .blog-text h3:hover, .comment-form-holder h3:hover, .comments-holder h3:hover, .project-details h3:hover, .blog-text h3 a:hover, .comment-form-holder h3 a:hover, .comments-holder h3 a:hover, .project-details h3 a:hover, .enter-wrap h3:hover, .fixed-info-container h3:hover, .fw-info-container h3:hover'),
                            'units'       =>'px',
                            'subtitle'    => __('Specify the Heading font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),						
                        array(
                            'id'          => 'typography-h4',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('H4', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h4, .fw-info-container h4, .fixed-info-container h4, .services-box-info h4'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the Heading font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),	
						),	
                        array(
                            'id'          => 'typography-h5',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('H5', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h5'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the Heading font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),	
                        array(
                            'id'          => 'typography-h6',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('H6', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('h6'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the Heading font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),

						array(
                            'id'          => 'typography-p',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('p, body', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('p.hs-description, .about-me-sub, p, body'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the content font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography-a',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('a', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('a, .copyright a, .bl-item-category a, .bl-item-meta a, .blog-single-meta .article-author a, .blog-single-links, .blog-single-links a, .media-heading a, .gs-back-to-list, ul.gallery-meta > li a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography-a-hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('a Hover Style', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('a:focus, a:hover, .blog-single-meta .article-author a:hover, .blog-single-links:hover, .blog-single-links a:hover, .media-heading a:hover, .gs-back-to-list:hover, ul.gallery-meta > li a:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the permalink font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography-span',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('span', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('span, .show-share span, .rpwe-time, .gli-alter-2 .gl-item-count'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the span font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography-input',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('input', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('input, .wpcf7-form input[type="text"], .wpcf7-form textarea, .wpcf7-form input[type="text"], .wpcf7-form textarea, .wpcf7-form input[type="email"], .form-control, .widget_search input[type="text"],.mc4wp-form input[type="text"], .mc4wp-form  input[type="email"]'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the input font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography-button',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Button', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.btn-primary,.wpcf7-form input[type=submit], .btn-white-bordered'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the button font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography-li',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('li', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('ul li, .project-details li, .services-box-info ul li'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the list Style font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						

						array(
			                'id' => 'notice_menucritical11',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Menu Font Options', 'primax'),
			                'desc' => esc_attr__('Menu Item font properties', 'primax')
			            ),					
                        array(
                            'id'          => 'typography-menu-main',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('ul.menu-list > li > a, body.dark-style #header ul.menu-list > li > a, body.dark-style #header ul.menu-list .sub-menu > li > a, ul.menu-list .sub-menu > li > a,ul.isotope-filter-links > li > a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the menu item font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						
						array(
                            'id'          => 'typography-menu-main-hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Menu Item Hover', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('#header ul.menu-list > li > a:hover, #header ul.menu-list > li.active > a, #menu .current-menu-item > a, #menu .current-menu-parent > a, body.dark-style #header ul.menu-list > li > a:hover, body.dark-style #header ul.menu-list > li.active > a, body.dark-style #header ul.menu-list .sub-menu > li > a:hover, body.dark-style #header ul.menu-list .sub-menu > li.current-menu-item > a, body.dark-style #header ul.menu-list .current-menu-parent > a, ul.menu-list .sub-menu > li > a:hover, ul.isotope-filter-links > li > a.active, ul.isotope-filter-links > li > a:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the menu item font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						
						
						array(
			                'id' => 'notice_widget',
			                'type' => 'info',
			                'notice' => true,
			                'style' => 'success',
			                'title' => esc_attr__('Widget List Item', 'primax'),
			                'desc' => esc_attr__('Widget List Item font properties', 'primax')
			            ),					
                        array(
                            'id'          => 'typography-widget-li',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Widget li Item', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.widget ul > li > a, .widget .rpwe-block h3 a, .widget_archive  ul  li  a,  .widget_categories  ul  li  a, .widget_archive  ul  li  a, body.dark-style .widget_categories  ul  li  a, body.dark-style .widget .rpwe-block h3 a'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the widget list item font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),
						
						array(
                            'id'          => 'typography-widget-li-hover',
                            'type'        => 'typography', 
                            'title'       => esc_attr__('Widget li Item Hover', 'primax'),
                            'google'      => true, 
                            'font-backup' => false,
                            'output'      => array('.widget ul > li > a:hover, .widget .rpwe-block h3 a:hover, .widget_archive  ul  li  a:hover, body.dark-style .widget_categories  ul  li  a:hover, body.dark-style .widget .rpwe-block h3 a:hover'),
                            'units'       =>'px',
                            'subtitle'    => esc_attr__('Specify the widget list item font properties.', 'primax'),
                            'default'     => array(
                            'color'       => false,
                            'font-style'  => false,
                            'font-family' => false,
                            'google'      => true,
                            'font-size'   => false,
                            'line-height' => false,
                            ),
						),

						
												
						
                    )
                ) );	
				
				
				 Redux::setSection( $opt_name, array(
                    'icon'   => 'el-icon-th-large',
                    'title'  => esc_attr__( 'Footer Options', 'primax' ),
                    'fields' => array(
					
					
					
					array(
							'id' => 'theme-cus-copy',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_attr__('Copy right Text', 'primax'),
							'desc' => esc_attr__('Footer copy right Text', 'primax')
							
					  ),
					
					array(
							'id' => 'copyright',
							'type' => 'editor',
							'wpautop'=>true,
							'compiler' => 'true',
							'title' => esc_attr__('Copyright text of the WebSite', 'primax'),
							'subtitle' => esc_attr__('Write a Copyright text of your WebSite', 'primax'),
							'default'          => '<p>&copy; 2017 . All Rights Reserved. Designed & develop <i class="fa fa-heart-o" aria-hidden="true"></i> By webRedox</p>',
							'args'   => array(
								'teeny'            => true,
								'textarea_rows'    => 10
							)
					),
					
					array(
							'id' => 'theme-footer-widget-opt',
							'type' => 'info',
		                    'notice' => true,
		                    'style' => 'info',
							'title' => esc_attr__('Footer Widget', 'primax'),
							'desc' => esc_attr__('Option For Enable/Disable Footer Widget Area.', 'primax')
							
					  ),
					
					array(
							'id' => 'theme-footer-widget-opt-main',
							'type' => 'button_set',
							'title' => esc_attr__('Footer Widget', 'primax'),
							'subtitle' => esc_attr__('', 'primax'),
							'desc' => '',
							'options' => array(
									'st1'=> esc_attr__('Disable', 'primax'),
									'st2' => esc_attr__('Enable', 'primax'),
									
									
							),
							'default'  => 'st1'
					),
					
					
					
					
					)
                ) );
				
				
    /*
     * <--- END SECTIONS
     */


    /*
     *
     * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
     *
     */

    /*
    *
    * --> Action hook examples
    *
    */

    // If Redux is running as a plugin, this will remove the demo notice and links
    //add_action( 'redux/loaded', 'remove_demo' );

    // Function to test the compiler hook and demo CSS output.
    // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
    //add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

    // Change the arguments after they've been declared, but before the panel is created
    //add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

    // Change the default value of a field after it's been set, but before it's been useds
    //add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

    // Dynamically add a section. Can be also used to modify sections/fields
    //add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');

    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    if ( ! function_exists( 'compiler_action' ) ) {
        function compiler_action( $options, $css, $changed_values ) {
            echo '<h1>The compiler hook has run!</h1>';
            echo "<pre>";
            print_r( $changed_values ); // Values that have changed since the last save
            echo "</pre>";
            //print_r($options); //Option values
            //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )
        }
    }

    /**
     * Custom function for the callback validation referenced above
     * */
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;

            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }

            $return['value'] = $value;

            if ( $error == true ) {
                $return['error'] = $field;
                $field['msg']    = 'your custom error message';
            }

            if ( $warning == true ) {
                $return['warning'] = $field;
                $field['msg']      = 'your custom warning message';
            }

            return $return;
        }
    }

    /**
     * Custom function for the callback referenced above
     */
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }

    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
     * so you must use get_template_directory_uri() if you want to use any of the built in icons
     * */
    if ( ! function_exists( 'dynamic_section' ) ) {
        function dynamic_section( $sections ) {
            //$sections = array();
            $sections[] = array(
                'title'  => esc_attr__( 'Section via hook', 'primax' ),
                'desc'   => esc_attr__( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'primax' ),
                'icon'   => 'el el-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }
    }

    /**
     * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
     * */
    if ( ! function_exists( 'change_arguments' ) ) {
        function change_arguments( $args ) {
            //$args['dev_mode'] = true;

            return $args;
        }
    }

    /**
     * Filter hook for filtering the default value of any given field. Very useful in development mode.
     * */
    if ( ! function_exists( 'change_defaults' ) ) {
        function change_defaults( $defaults ) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }
    }

    /**
     * Removes the demo link and the notice of integrated demo from the redux-primax plugin
     */
    if ( ! function_exists( 'remove_demo' ) ) {
        function remove_demo() {
            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
                remove_filter( 'plugin_row_meta', array(
                    ReduxFrameworkPlugin::instance(),
                    'plugin_metalinks'
                ), null, 2 );

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
            }
        }
    }

